Module exporter

Module exporter 

Defines a trait for exporting Textures to arbitrary data.

Structs

BackgroundColorSettings
Background color settings for sections of the image without regions.
ImageExporter
Exporter type for images.

Traits

Exporter
Converter for a Texture to type Output.

Type Aliases

ExportResult
Result of exporting a texture.